@@ -1,12 +1,18 @@
 tDWT <- function (tnsr) {
+  # Performs the Discrete Wavelet Transform of a 3-D Tensor.
+  # Input: 3D tensor
+  # Output: 3D tensor where a DWT has been performed along
+  # mode 3.
+
   if (tnsr@num_modes != 3)
-    stop("T-SVD only implemented for 3d so far")
+    stop("tDwt only implemented for 3d so far")
 
   modes <- tnsr@modes
   n1 <- modes[1]
   n2 <- modes[2]
   n3 <- modes[3]
 
+  #  Check to see if mode 3 is a power of 2.
   if (sum(as.numeric(intToBits(n3))) != 1)
     stop("Mode 3 must be a power of 2 otherwise using 0 padding")
 
