@@ -1,10 +1,17 @@
-tLU <- function(tnsr,tform) {
+tLU <- function(tnsr,tform)
+{
+  # Performs a tensor LU decomposition on any 3-mode tensor
+  # using any discrete transform.
+
+  # Input: A square matrix A.
+  # Output: Matrices L and U so that A=LU.
+
   modes <- tnsr@modes
   n1 <- modes[1]
   n2 <- modes[2]
   n3 <- modes[3]
   if (tnsr@num_modes != 3)
-    stop("T-SVD only implemented for 3d so far")
+    stop("tLU only implemented for 3d so far")
   if (tform=="dwt"){
     if (sum(as.numeric(intToBits(n3))) != 1)
       stop("Mode 3 must be a power of 2 otherwise using 0 padding")
