@@ -1,10 +1,19 @@
-tSVD <- function(tnsr,tform) {
+tSVD <- function(tnsr,tform)
+{
+  # Performs a tensor singular value decomposition on any 3-mode
+  # tensor using any discrete transform.
+
+  # Input: A, 3-mode tensor
+  # Output: Tensors U (left singular value object),
+  # V (right singular value object) and
+  # S, a diagonal tensor so that A=USV^T.
+
   modes <- tnsr@modes
   n1 <- modes[1]
   n2 <- modes[2]
   n3 <- modes[3]
   if (tnsr@num_modes != 3)
-    stop("T-SVD only implemented for 3d so far")
+    stop("tSVD only implemented for 3d so far")
   if (tform=="dwt"){
     if (sum(as.numeric(intToBits(n3))) != 1)
     stop("Mode 3 must be a power of 2 otherwise using 0 padding")
